#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2020 Mopi
set -o errexit

###
# Cats are Liquid 2
# send your bug reports to contact@dotslashplay.it
###

script_version=20230625.1

# Set game-specific variables

GAME_ID='cats-are-liquid-2'
GAME_NAME='Cats are Liquid - A Better Place'

ARCHIVE_ITCH='CaL-ABP-Linux.zip'
ARCHIVE_ITCH_URL='https://lastquarterstudios.itch.io/cats-are-liquid-a-better-place'
ARCHIVE_ITCH_MD5='a61524e809870b026dc8a993b177b9b9'
ARCHIVE_ITCH_SIZE='440000'
ARCHIVE_ITCH_VERSION='1.0-itch1'
ARCHIVE_ITCH_TYPE='zip'

ARCHIVE_GAME_BIN_PATH='Linux'
ARCHIVE_GAME_BIN_FILES='CaL-ABP-Linux.x86_64 CaL-ABP-Linux_Data/Mono CaL-ABP-Linux_Data/Plugins'

ARCHIVE_GAME_DATA_PATH='Linux'
ARCHIVE_GAME_DATA_FILES='CaL-ABP-Linux_Data'

DATA_DIRS='./logs'

APP_MAIN_TYPE='native'
APP_MAIN_EXE='CaL-ABP-Linux.x86_64'
APP_MAIN_ICON='CaL-ABP-Linux_Data/Resources/UnityPlayer.png'
# Common Unity3D tweaks
APP_MAIN_PRERUN='# Work around Unity3D poor support for non-US locales
export LANG=C'
# Use a per-session dedicated file for logs
# shellcheck disable=SC2016
APP_MAIN_OPTIONS='-logFile ./logs/$(date +%F-%R).log'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_LIGHTING_ID $PKG_DATA_ID glibc libstdc++"

# Load common functions

target_version='2.12'

if [ -z "$PLAYIT_LIB2" ]; then
	: "${XDG_DATA_HOME:="$HOME/.local/share"}"
	for path in\
		"$PWD"\
		"$XDG_DATA_HOME/play.it"\
		'/usr/local/share/games/play.it'\
		'/usr/local/share/play.it'\
		'/usr/share/games/play.it'\
		'/usr/share/play.it'
	do
		if [ -e "$path/libplayit2.sh" ]; then
			PLAYIT_LIB2="$path/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Get game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Clean up temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write 'APP_MAIN'

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
