#!/bin/sh
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2018 Antoine Le Gonidec <vv221@dotslahsplay.it>
set -o errexit

###
# Divinity: Original Sin
# send your bug reports to contact@dotslashplay.it
###

script_version=20230916.1

PLAYIT_COMPATIBILITY_LEVEL='2.26'

GAME_ID='divinity-original-sin'
GAME_NAME='Divinity: Original Sin'

ARCHIVE_BASE_0='divinity_original_sin_enhanced_edition_en_2_0_119_430_ch_17075.sh'
ARCHIVE_BASE_0_MD5='89f526c1030d6d352b7df65361ab71e6'
ARCHIVE_BASE_0_SIZE='11000000'
ARCHIVE_BASE_0_VERSION='2.0.119.430-gog17075'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/divinity_original_sin_enhanced_edition'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_LIBS_BIN_FILES='
libbink2.so
libCoreLib.so
libGameEngine.so
libGLEW.so.1.10
libGLEW.so.1.10.0
libicudata.so.54
libicuuc.so.54
libjpeg.so.8
libjpeg.so.8.0.2
libOGLBinding.so
libosiris.so.2
libRenderFramework.so
libSDL2-2.0.so.1
libsteam_api.so'
CONTENT_GAME_BIN_FILES='
EoCApp'
CONTENT_GAME_L10N_FILES='
Data/Localization'
CONTENT_GAME_DATA_FILES='
DigitalMap
Data/*.pak'

FAKE_HOME_PERSISTENT_DIRECTORIES='
Larian Studios/Divinity Original Sin Enhanced Edition'
## TODO - We could build lang-specific localization packages,
##        instead of encorcing an localization based on the user environment.
USER_PERSISTENT_FILES='
Data/Localization/language.lsx'

APP_MAIN_EXE='EoCApp'
APP_MAIN_ICON='../support/icon.png'
## Set language based on environment
APP_MAIN_PRERUN='# Set language based on environment
case "${LANG%_*}" in
	('\''fr'\'') lang='\''French'\'' ;;
	('\''de'\'') lang='\''German'\'' ;;
	('\''it'\'') lang='\''Italian'\'' ;;
	('\''pl'\'') lang='\''Polish'\'' ;;
	('\''zh'\'') lang='\''Chinese'\'' ;;
	('\''ru'\'') lang='\''Russian'\'' ;;
	('\''es'\'') lang='\''Spanish'\'' ;;
	('\''en'\''|*) lang='\''English'\'' ;;
esac
language_file="${USER_PERSISTENT_PATH}/Data/Localization/language.lsx"
sed_pattern=$(printf '\''s/id="Value" value=".*"/id="Value" value="%s" type="20"/g'\'' "$lang")
sed --in-place "$sed_pattern" "$language_file"
'

PACKAGES_LIST='PKG_BIN PKG_L10N PKG_DATA'

PKG_L10N_ID="${GAME_ID}-l10n"
PKG_L10N_DESCRIPTION='localization'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_L10N_ID $PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libc++.so.1
libc++abi.so.1
libdl.so.2
libgcc_s.so.1
libGL.so.1
libm.so.6
libopenal.so.1
libpng16.so.16
libpthread.so.0
librt.so.1
libz.so.1'

PRELOAD_HACKS_LIST='
HACK_MESA'

# LD_PRELOAD shim working around a crash with Mesa drivers
# cf. https://gitlab.freedesktop.org/mesa/mesa/-/issues/999
HACK_MESA_NAME='mesa-hack'
HACK_MESA_PACKAGE='PKG_BIN'
HACK_MESA_SOURCE='
#ifndef _GNU_SOURCE
#define _GNU_SOURCE
#endif
#include <dlfcn.h>
#include <GL/gl.h>
#include <string.h>
#define _GLX_PUBLIC
const GLubyte *GLAPIENTRY glGetString( GLenum name ) {
	static void *next = NULL;
	static const char *vendor = "ATI Technologies, Inc.";
	if(name == GL_VENDOR)
		return (const GLubyte *)vendor;
	if(!next)
		next = dlsym(RTLD_NEXT, "glGetString");
	return ((const GLubyte *GLAPIENTRY (*)(GLenum))next)(name);
}
_GLX_PUBLIC void (*glXGetProcAddressARB(const GLubyte * procName)) (void) {
	static void *next = NULL;
	if (
		strcmp((const char *) procName, "glNamedStringARB") == 0 ||
		strcmp((const char *) procName, "glDeleteNamedStringARB") == 0 ||
		strcmp((const char *) procName, "glCompileShaderIncludeARB") == 0 ||
		strcmp((const char *) procName, "glIsNamedStringARB") == 0 ||
		strcmp((const char *) procName, "glGetNamedStringARB") == 0 ||
		strcmp((const char *) procName, "glGetNamedStringivARB") == 0
	) return NULL;
	if(!next)
		next = dlsym(RTLD_NEXT, "glXGetProcAddressARB");
	return ((_GLX_PUBLIC void (*(*)(const GLubyte *))(void))next)(procName);
}
'

# Load common functions

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Build and include the LD_PRELOAD shim working around a crash with Mesa drivers

PKG='PKG_BIN'
hacks_inclusion_default

# Ensure availability of libpcre.so.3

case "$(option_value 'package')" in
	('arch')
		# libpcre.so.3 is not provided from Arch Linux repositories
		CONTENT_LIBS_BIN_FILES="$(content_files 'LIBS_BIN')
		libpcre.so.3
		libpcre.so.3.13.1"
	;;
	(*)
		dependencies_add_native_libraries 'PKG_BIN' 'libpcre.so.3'
	;;
esac

# Extract game data

archive_extraction_default

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
