#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Mopi
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
# SPDX-FileCopyrightText: © 2018 BetaRays
# SPDX-FileCopyrightText: © 2021 Hoël Bézier
set -o errexit

###
# Don't Starve
# send your bug reports to contact@dotslashplay.it
###

script_version=20230901.2

GAME_ID='dont-starve'
GAME_NAME='Donʼt Starve'

ARCHIVE_BASE_1='don_t_starve_554439_66995.sh'
ARCHIVE_BASE_1_MD5='783646e973fdcc1fefad470da14f6855'
ARCHIVE_BASE_1_SIZE='660000'
ARCHIVE_BASE_1_VERSION='554439-gog66995'
ARCHIVE_BASE_1_URL='https://www.gog.com/game/dont_starve'

ARCHIVE_BASE_0='don_t_starve_4294041_41439.sh'
ARCHIVE_BASE_0_MD5='05baa7fb659f79d4676a59bf3a64fc76'
ARCHIVE_BASE_0_SIZE='950000'
ARCHIVE_BASE_0_VERSION='4294041-gog41439'

ARCHIVE_BASE_OLDPATH_0='don_t_starve_en_222215_22450.sh'
ARCHIVE_BASE_OLDPATH_0_MD5='611cd70afd9b9feb3aca4d1eaf9ebbda'
ARCHIVE_BASE_OLDPATH_0_SIZE='760000'
ARCHIVE_BASE_OLDPATH_0_VERSION='276758-gog22450'

ARCHIVE_BASE_MULTIARCH_2='don_t_starve_en_20171215_17629.sh'
ARCHIVE_BASE_MULTIARCH_2_MD5='f7dda3b3bdb15ac62acb212a89b24623'
ARCHIVE_BASE_MULTIARCH_2_SIZE='670000'
ARCHIVE_BASE_MULTIARCH_2_VERSION='246924-gog17629'

ARCHIVE_BASE_MULTIARCH_1='gog_don_t_starve_2.7.0.9.sh'
ARCHIVE_BASE_MULTIARCH_1_MD5='01d7496de1c5a28ffc82172e89dd9cd6'
ARCHIVE_BASE_MULTIARCH_1_SIZE='660000'
ARCHIVE_BASE_MULTIARCH_1_VERSION='222215-gog2.7.0.9'

ARCHIVE_BASE_MULTIARCH_0='gog_don_t_starve_2.6.0.8.sh'
ARCHIVE_BASE_MULTIARCH_0_MD5='2b0d363bea53654c0267ae424de7130a'
ARCHIVE_BASE_MULTIARCH_0_SIZE='650000'
ARCHIVE_BASE_MULTIARCH_0_VERSION='198251-gog2.6.0.8'

CONTENT_PATH_DEFAULT='data/noarch/game'
CONTENT_PATH_DEFAULT_OLDPATH='data/noarch/game/dontstarve64'
CONTENT_PATH_DEFAULT_MULTIARCH='data/noarch/game/dontstarve64'
# TODO: Check if we can drop the shipped SDL2 library.
CONTENT_LIBS_BIN64_PATH="${CONTENT_PATH_DEFAULT}/bin/lib64"
CONTENT_LIBS_BIN64_PATH_OLDPATH="${CONTENT_PATH_OLDPATH}/bin/lib64"
CONTENT_LIBS_BIN64_PATH_MULTIARCH="${CONTENT_PATH_MULTIARCH}/bin/lib64"
CONTENT_LIBS_BIN64_FILES='
libfmodevent64.so
libfmodevent64-4.44.??.so
libfmodex64.so
libfmodex64-4.44.??.so
libSDL2.so
libSDL2-2.0.so.0
libSDL2-2.0.so.0.0.0'
CONTENT_LIBS_BIN32_PATH='data/noarch/game/dontstarve32/bin/lib32'
CONTENT_LIBS_BIN32_FILES='
libfmodevent.so
libfmodevent-4.44.??.so
libfmodex.so
libfmodex-4.44.??.so
libSDL2.so
libSDL2-2.0.so.0
libSDL2-2.0.so.0.0.0'
CONTENT_GAME_BIN64_FILES='
bin/dontstarve
*.json'
CONTENT_GAME_BIN32_PATH='data/noarch/game/dontstarve32'
CONTENT_GAME_BIN32_FILES='
bin/dontstarve
*.json'
CONTENT_GAME_DATA_FILES='
data
mods
dontstarve.xpm'

USER_PERSISTENT_DIRECTORIES='
mods'

APP_MAIN_EXE='bin/dontstarve'
APP_MAIN_ICON='dontstarve.xpm'
## Run the game binary from its parent directory
APP_MAIN_PRERUN='# Run the game binary from its parent directory
cd "$(dirname "$APP_EXE")"
APP_EXE=$(basename "$APP_EXE")
'

PACKAGES_LIST='PKG_BIN64 PKG_DATA'
PACKAGES_LIST_MULTIARCH='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN64_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN32_DEPS="$PKG_BIN_DEPS"
PKG_BIN64_DEPS="$PKG_BIN_DEPS"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libcurl-gnutls.so.4
libdl.so.2
libgcc_s.so.1
libGL.so.1
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6'
PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Write launchers

PKG='PKG_BIN64'
launchers_write
case "$(context_archive)" in
	('ARCHIVE_BASE_MULTIARCH_'*)
		PKG='PKG_BIN32'
		launchers_write
	;;
esac

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
