#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Iris and the Giant
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211024.3

# Set game-specific variables

GAME_ID='iris-and-the-giant'
GAME_NAME='Iris and the Giant'

ARCHIVE_BASE_0='iris_and_the_giant_1_1_1_2_37953.sh'
ARCHIVE_BASE_0_MD5='da4767fb2bdcc4d4146958b449de06b4'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='530000'
ARCHIVE_BASE_0_VERSION='1.1.1.2-gog37953'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/iris_and_the_giant_deckbuilding_roguelike'

UNITY3D_NAME='Iris and the Giant'

ARCHIVE_GAME_BIN_PATH='data/noarch/game'
ARCHIVE_GAME_BIN_FILES='
Iris?and?the?Giant.x86_64
Iris?and?the?Giant_Data/MonoBleedingEdge
Iris?and?the?Giant_Data/Plugins'

ARCHIVE_GAME_DATA_PATH='data/noarch/game'
ARCHIVE_GAME_DATA_FILES='
Iris?and?the?Giant_Data
app.info
boot.config
data.unity3d
sharedassets0.resource'

PACKAGES_LIST='PKG_BIN PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID libc.so.6 libstdc++.so.6 libz.so.1 libgtk-x11-2.0.so.0 libgdk-x11-2.0.so.0 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0 freetype"
PKG_BIN_DEPS_ARCH='atk glib2 pango cairo fontconfig'
PKG_BIN_DEPS_DEB='libatk1.0-0, libglib2.0-0, libpangoft2-1.0-0, libpangocairo-1.0-0, libcairo2, libpango-1.0-0, libfontconfig1'
PKG_BIN_DEPS_GETNOO='dev-libs/atk dev-libs/glib x11-libs/pango x11-libs/cairo media-libs/fontconfig'

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"
 
# Extract game data
 
extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout
 
# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Include game icon
 
PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers
 
PKG='PKG_BIN'
launchers_write 'APP_MAIN'
 
# Build package
 
write_metadata
build_pkg
 
# Clean up
 
rm --recursive "$PLAYIT_WORKDIR"
 
# Print instructions
 
print_instructions
 
exit 0
