#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2017 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Legend of Grimrock
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20220705.1

GAME_ID='legend-of-grimrock'
GAME_NAME='Legend of Grimrock'

ARCHIVE_BASE_0='gog_legend_of_grimrock_2.1.0.5.sh'
ARCHIVE_BASE_0_MD5='b63089766247484f5d2b214d924425f6'
ARCHIVE_BASE_0_TYPE='mojosetup'
ARCHIVE_BASE_0_SIZE='690000'
ARCHIVE_BASE_0_VERSION='1.3.7-gog2.1.0.5'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/legend_of_grimrock'

CONTENT_PATH_DEFAULT='data/noarch/game'
ARCHIVE_DOC_DATA_FILES='
README.linux'
ARCHIVE_GAME_BIN32_FILES='
Grimrock.bin.x86
lib'
ARCHIVE_GAME_BIN64_FILES='
Grimrock.bin.x86_64
lib64'
ARCHIVE_GAME_DATA_FILES='
grimrock.dat
grimrock.png'

APP_MAIN_TYPE='native'
APP_MAIN_EXE_BIN32='Grimrock.bin.x86'
APP_MAIN_EXE_BIN64='Grimrock.bin.x86_64'
APP_MAIN_ICON='grimrock.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

# TODO - Gentoo dependencies are missing.
PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID libc.so.6 libGL.so.1 libopenal.so.1 libSDL2-2.0.so.0 libvorbisfile.so.3"
PKG_BIN32_DEPS_DEB='libfreeimage3, libminizip1'
PKG_BIN32_DEPS_ARCH='freeimage minizip'

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"
PKG_BIN64_DEPS_DEB="$PKG_BIN32_DEPS_DEB"
PKG_BIN64_DEPS_ARCH='freeimage minizip'

# Load common functions

target_version='2.16'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
