#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine "vv221/vv222" Le Gonidec
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Lieve Oma
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20211013.1

# Set game-specific variables

GAME_ID='lieve-oma'
GAME_NAME='Lieve Oma'

ARCHIVE_BASE_0='Lieve Oma Linux Universal.zip'
ARCHIVE_BASE_0_MD5='b33c1f38503a221ce82139a5435c3577'
ARCHIVE_BASE_0_SIZE='770000'
ARCHIVE_BASE_0_VERSION='1.0-itch'
ARCHIVE_BASE_0_URL='https://vltmn.itch.io/lieve-oma'

UNITY3D_NAME='Lieve Oma'

ARCHIVE_DOC_DATA_PATH='Lieve Oma Linux Universal'
ARCHIVE_DOC_DATA_FILES='README.png'

ARCHIVE_GAME_BIN32_PATH='Lieve Oma Linux Universal'
ARCHIVE_GAME_BIN32_FILES='
Lieve?Oma.x86
Lieve?Oma_Data/Mono/x86
Lieve?Oma_Data/Plugins/x86'

ARCHIVE_GAME_BIN64_PATH='Lieve Oma Linux Universal'
ARCHIVE_GAME_BIN64_FILES='
Lieve?Oma.x86_64
Lieve?Oma_Data/Mono/x86_64
Lieve?Oma_Data/Plugins/x86_64'

ARCHIVE_GAME_DATA_PATH='Lieve Oma Linux Universal'
ARCHIVE_GAME_DATA_FILES='Lieve?Oma_Data'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID xcursor libxrandr libc.so.6 libstdc++.so.6 libGL.so.1 libX11.so.6"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"
prepare_package_layout

# Delete temporary files

rm --recursive "$PLAYIT_WORKDIR/gamedata"

# Get game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write 'APP_MAIN'
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
