#!/bin/sh
set -o errexit

###
# Copyright (c) 2015-2021, Antoine Le Gonidec <vv221@dotslashplay.it>
# Copyright (c) 2016-2021, Mopi
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
# 1. Redistributions of source code must retain the above copyright notice,
# this list of conditions and the following disclaimer.
#
# 2. Redistributions in binary form must reproduce the above copyright notice,
# this list of conditions and the following disclaimer in the documentation
# and/or other materials provided with the distribution.
#
# This software is provided by the copyright holders and contributors "as is"
# and any express or implied warranties, including, but not limited to, the
# implied warranties of merchantability and fitness for a particular purpose
# are disclaimed. In no event shall the copyright holder or contributors be
# liable for any direct, indirect, incidental, special, exemplary, or
# consequential damages (including, but not limited to, procurement of
# substitute goods or services; loss of use, data, or profits; or business
# interruption) however caused and on any theory of liability, whether in
# contract, strict liability, or tort (including negligence or otherwise)
# arising in any way out of the use of this software, even if advised of the
# possibility of such damage.
###

###
# Lumini
# build native packages from the original installers
# send your bug reports to contact@dotslashplay.it
###

script_version=20210914.2

# Set game-specific variables

GAME_ID='lumini'
GAME_NAME='Lumini'

ARCHIVE_BASE_0='Lumini_DRMfree_Linux.zip'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/lumini'
ARCHIVE_BASE_0_MD5='7d70f1824be9ab701cf9d52fb12a039a'
ARCHIVE_BASE_0_SIZE='4700000'
ARCHIVE_BASE_0_VERSION='1.0-humble1'

UNITY3D_NAME='lumini'

ARCHIVE_GAME_BIN32_PATH='.'
ARCHIVE_GAME_BIN32_FILES="
${UNITY3D_NAME}.x86
${UNITY3D_NAME}_Data/Mono/x86
${UNITY3D_NAME}_Data/Plugins/x86"

ARCHIVE_GAME_BIN64_PATH='.'
ARCHIVE_GAME_BIN64_FILES="
${UNITY3D_NAME}.x86_64
${UNITY3D_NAME}_Data/Mono/x86_64
${UNITY3D_NAME}_Data/Plugins/x86_64"

ARCHIVE_GAME_DATA_PATH='.'
ARCHIVE_GAME_DATA_FILES="
${UNITY3D_NAME}_Data
SavesDir"

DATA_DIRS='./SavesDir'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN32_DEPS="$PKG_DATA_ID xcursor libxrandr libc.so.6 libstdc++.so.6 libGL.so.1 libgtk-x11-2.0.so.0 libX11.so.6 libgdk_pixbuf-2.0.so.0 libgobject-2.0.so.0 libglib-2.0.so.0"

PKG_BIN64_ARCH='64'
PKG_BIN64_DEPS="$PKG_BIN32_DEPS"

# Load common functions

target_version='2.14'

if [ -z "$PLAYIT_LIB2" ]; then
	for path in \
		"$PWD" \
		"${XDG_DATA_HOME:="$HOME/.local/share"}/play.it" \
		'/usr/local/share/games/play.it' \
		'/usr/local/share/play.it' \
		'/usr/share/games/play.it' \
		'/usr/share/play.it'
	do
		if [ -e "${path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
# shellcheck source=play.it-2/lib/libplayit2.sh
. "$PLAYIT_LIB2"

# Extract game data

extract_data_from "$SOURCE_ARCHIVE"

# Work around the massive files duplication between the 32-bit and 64-bit builds

(
	cd "${PLAYIT_WORKDIR}/gamedata"
	# Merge assets directories for the 32-bit and 64-bit builds
	mv lumini_Linux32_Data "$(unity3d_name)_Data"
	cp --force --recursive --link lumini_Linux64_Data/* "$(unity3d_name)_Data"
	rm --force --recursive lumini_Linux64_Data
	# Rename the binaries
	mv lumini_Linux32.x86    "$(unity3d_name).x86"
	mv lumini_Linux64.x86_64 "$(unity3d_name).x86_64"
)

# Delete unused files

(
	cd "${PLAYIT_WORKDIR}/gamedata"
	# Delete files that are not used by the Linux build
	rm --force --recursive \
		"$(unity3d_name)_Data"/Mono/x86*/*.dll \
		"$(unity3d_name)_Data"/Mono/x86*/*.meta \
		"$(unity3d_name)_Data"/Plugins/x86*/*.dll \
		"$(unity3d_name)_Data"/Plugins/x86*/*.meta \
		"$(unity3d_name)_Data"/Plugins/*.bundle
	# Delete duplicated libraries
	rm --force \
		"$(unity3d_name)_Data"/Mono/x86*/libfmod.so \
		"$(unity3d_name)_Data"/Mono/x86*/libfmodstudio.so \
		"$(unity3d_name)_Data"/Mono/x86*/ScreenSelector.so
)

# Prepare the packages directories

prepare_package_layout

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Include game icon

PKG='PKG_DATA'
icons_get_from_package 'APP_MAIN'

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write 'APP_MAIN'
done

# Build package

write_metadata
build_pkg

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

# Print instructions

print_instructions

exit 0
