#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 Mopi
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# Rakuen
# send your bug reports to contact@dotslashplay.it
###

script_version=20230916.1

GAME_ID='rakuen'
GAME_NAME='Rakuen'

ARCHIVE_BASE_0='rakuen_linux.tgz'
ARCHIVE_BASE_0_MD5='cae92b2e92cd4e15796a7faa765d2e64'
ARCHIVE_BASE_0_SIZE='200000'
ARCHIVE_BASE_0_VERSION='1.0-humble1'
ARCHIVE_BASE_0_URL='https://www.humblebundle.com/store/rakuen'

CONTENT_PATH_DEFAULT='Rakuen'
CONTENT_LIBS_BIN32_PATH="${CONTENT_PATH_DEFAULT}/lib"
## TODO: Drop all shipped libraries that could be replaced with system ones.
CONTENT_LIBS_BIN32_FILES='
libfreetype.so.6
libjpeg.so.62
libogg.so.0
libopenal.so.1
libphysfs.so.1
libpixman-1.so.0
libpng16.so.16
libruby.so.2.1
libSDL2-2.0.so.0
libSDL2_image-2.0.so.0
libSDL2_ttf-2.0.so.0
libSDL_sound-1.0.so.1
libsigc-2.0.so.0
libvorbisfile.so.3
libvorbis.so.0
libz.so.1'
CONTENT_LIBS_BIN64_PATH="${CONTENT_PATH_DEFAULT}/lib64"
## TODO: Drop all shipped libraries that could be replaced with system ones.
CONTENT_LIBS_BIN64_FILES='
libfreetype.so.6
libjpeg.so.62
libogg.so.0
libopenal.so.1
libphysfs.so.1
libpixman-1.so.0
libpng16.so.16
libruby.so.2.1
libSDL2-2.0.so.0
libSDL2_image-2.0.so.0
libSDL2_ttf-2.0.so.0
libSDL_sound-1.0.so.1
libsigc-2.0.so.0
libvorbisfile.so.3
libvorbis.so.0
libz.so.1'
CONTENT_GAME_BIN32_FILES='
Rakuen.x86'
CONTENT_GAME_BIN64_FILES='
Rakuen.amd64'
CONTENT_GAME_DATA_FILES='
Audio
Engine.ini
Engine.rgssad
Fonts
icon.png
mkxp
mkxp.conf'
CONTENT_DOC_DATA_FILES='
*.pdf'

USER_PERSISTENT_FILES='
Engine.ini
mkxp.conf'

## TODO: Check why we do not use a standard prefix (symlinks farm).
APP_MAIN_PREFIX_TYPE='none'
APP_MAIN_EXE_BIN32='Rakuen.x86'
APP_MAIN_EXE_BIN64='Rakuen.amd64'
APP_MAIN_ICON='icon.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN64_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN32_DEPS="$PKG_BIN_DEPS"
PKG_BIN64_DEPS="$PKG_BIN_DEPS"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libcrypt.so.1
libc.so.6
libdl.so.2
libgcc_s.so.1
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6'
PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'
(
	cd "${PLAYIT_WORKDIR}/gamedata/$(content_path_default)"

	# Prevent inclusion of MacOS archive junk files
	find -type f -name '._*' -delete
)

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN32'
launchers_write
PKG='PKG_BIN64'
launchers_write

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
