#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2022 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# The Bard's Tale 4
# send your bug reports to contact@dotslashplay.it
###

script_version=200230623.2

GAME_ID='the-bards-tale-4'
GAME_NAME='The Bardʼs Tale Ⅳ'

ARCHIVE_BASE_0='the_bard_s_tale_iv_director_s_cut_update_3_34066.sh'
ARCHIVE_BASE_0_MD5='695a04c36fe4a5ff2a53b93062151047'
ARCHIVE_BASE_0_SIZE='39000000'
ARCHIVE_BASE_0_VERSION='4.20.1-gog34066'
ARCHIVE_BASE_0_URL='https://www.gog.com/game/the_bards_tale_iv_directors_cut_standard_edition'

CONTENT_PATH_DEFAULT='data/noarch/game'
# TODO - Check if the libraries provided under "Engine" could be moved to /usr/lib/games.
CONTENT_GAME_BIN_FILES='
BardsTale4/Binaries/Linux/BardsTale4-Linux-Shipping
Engine'
CONTENT_GAME_DATA_MOVIES_1_FILES='
BardsTale4/Content/Movies/*.mp3
BardsTale4/Content/Movies/*.mp4
BardsTale4/Content/Movies/*.wav
BardsTale4/Content/Movies/Epilogue_Credits
BardsTale4/Content/Movies/PoMMovies'
CONTENT_GAME_DATA_MOVIES_2_FILES='
BardsTale4/Content/Movies/Anamatics
BardsTale4/Content/Movies/BardIV_FireLogo_Img_Sequence
BardsTale4/Content/Movies/BardIV_InxileLogo_Img_Sequence
BardsTale4/Content/Movies/BardIV_LegalScreen_Img_Sequence
BardsTale4/Content/Movies/Opening_Img_Sequence
BardsTale4/Content/Movies/SpecialFeatures'
CONTENT_GAME_DATA_PAKS_1_FILES='
BardsTale4/Content/Paks/pakchunk0-LinuxNoEditor.pak.split00
BardsTale4/Content/Paks/pakchunk0-LinuxNoEditor.pak.split01
BardsTale4/Content/Paks/pakchunk1-LinuxNoEditor.pak'
CONTENT_GAME_DATA_PAKS_2_FILES='
BardsTale4/Content/Paks/pakchunk2-LinuxNoEditor.pak.split00
BardsTale4/Content/Paks/pakchunk2-LinuxNoEditor.pak.split01
BardsTale4/Content/Paks/pakchunk50-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk60-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk70-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk80-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk90-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk100-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk110-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk120-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk130-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk140-LinuxNoEditor.pak
BardsTale4/Content/Paks/pakchunk150-LinuxNoEditor.pak'
CONTENT_GAME_DATA_FILES='
BardsTale4/Content'

APP_MAIN_EXE='BardsTale4/Binaries/Linux/BardsTale4-Linux-Shipping'
APP_MAIN_ICON='../support/icon.png'

PACKAGES_LIST='PKG_BIN PKG_DATA_MOVIES_1 PKG_DATA_MOVIES_2 PKG_DATA_PAKS_1 PKG_DATA_PAKS_2 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_DATA_MOVIES_1_ID="${PKG_DATA_ID}-movies-1"
PKG_DATA_MOVIES_1_DESCRIPTION="$PKG_DATA_DESCRIPTION - movies - 1"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_MOVIES_1_ID"

PKG_DATA_MOVIES_2_ID="${PKG_DATA_ID}-movies-2"
PKG_DATA_MOVIES_2_DESCRIPTION="$PKG_DATA_DESCRIPTION - movies - 2"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_MOVIES_2_ID"

PKG_DATA_PAKS_1_ID="${PKG_DATA_ID}-paks-1"
PKG_DATA_PAKS_1_DESCRIPTION="$PKG_DATA_DESCRIPTION - paks - 1"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_PAKS_1_ID"

PKG_DATA_PAKS_2_ID="${PKG_DATA_ID}-paks-2"
PKG_DATA_PAKS_2_DESCRIPTION="$PKG_DATA_DESCRIPTION - paks - 2"
PKG_DATA_DEPS="$PKG_DATA_DEPS $PKG_DATA_PAKS_2_ID"

PKG_BIN_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libdl.so.2
libgcc_s.so.1
libm.so.6
libpthread.so.0
librt.so.1
libstdc++.so.6'

# Load common functions

target_version='2.23'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Set package scripts to rebuild the full files from their chunks

for file_path in \
	'BardsTale4/Content/Paks/pakchunk0-LinuxNoEditor.pak' \
	'BardsTale4/Content/Paks/pakchunk2-LinuxNoEditor.pak'
do
	PKG_DATA_POSTINST_RUN="${PKG_DATA_POSTINST_RUN:-}
	$(huge_file_concatenate "$file_path")"
	PKG_DATA_PRERM_RUN="${PKG_DATA_PRERM_RUN:-}
	$(huge_file_delete "$file_path")"
done

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

ARCHIVE_OPTIONAL_ICONS='the-bards-tale-4_icons.tar.gz'
ARCHIVE_OPTIONAL_ICONS_URL='https://downloads.dotslashplay.it/games/the-bards-tale-4/'
ARCHIVE_OPTIONAL_ICONS_MD5='aede8ef2c559ecf8e69e1f5ffef7432d'

CONTENT_ICONS_PATH='.'
CONTENT_ICONS_FILES='
16x16
32x32
64x64
128x128
256x256'

archive_initialize_optional \
	'ARCHIVE_ICONS' \
	'ARCHIVE_OPTIONAL_ICONS'

if [ -n "${ARCHIVE_ICONS:-}" ]; then
	archive_extraction 'ARCHIVE_ICONS'
	content_inclusion 'PKG_DATA' 'ICONS' "$(path_icons)"
else
	PKG='PKG_DATA'
	icons_inclusion
fi

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

PKG='PKG_BIN'
launchers_write

# Build package

write_metadata
build_pkg

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
