#!/bin/sh
# SPDX-License-Identifier: BSD-2-Clause
# SPDX-FileCopyrightText: © 2018 BetaRays
# SPDX-FileCopyrightText: © 2021 Antoine Le Gonidec <vv221@dotslashplay.it>
set -o errexit

###
# unEpic
# send your bug reports to contact@dotslashplay.it
###

script_version=20230902.1

GAME_ID='unepic'
GAME_NAME='unEpic'

ARCHIVE_BASE_HUMBLE_0='unepic-15005.run'
ARCHIVE_BASE_HUMBLE_0_MD5='940824c4de6e48522845f63423e87783'
## This MojoSetup installer does not seem to be based on Makeself,
## so our regular type detection and extraction code do not work.
ARCHIVE_BASE_HUMBLE_0_EXTRACTOR='bsdtar'
ARCHIVE_BASE_HUMBLE_0_VERSION='1.50.05-humble141208'
ARCHIVE_BASE_HUMBLE_0_SIZE='360000'
ARCHIVE_BASE_HUMBLE_0_URL='https://www.humblebundle.com/store/unepic'

ARCHIVE_BASE_GOG_1='unepic_en_1_51_01_20608.sh'
ARCHIVE_BASE_GOG_1_MD5='88d98eb09d235fe3ca00f35ec0a014a3'
ARCHIVE_BASE_GOG_1_VERSION='1.51.01-gog20608'
ARCHIVE_BASE_GOG_1_SIZE='380000'
ARCHIVE_BASE_GOG_1_URL='https://www.gog.com/game/unepic'

ARCHIVE_BASE_GOG_0='gog_unepic_2.1.0.4.sh'
ARCHIVE_BASE_GOG_0_MD5='341556e144d5d17ae23d2b0805c646a1'
ARCHIVE_BASE_GOG_0_SIZE='380000'
ARCHIVE_BASE_GOG_0_VERSION='1.50.05-gog2.1.0.4'

CONTENT_PATH_DEFAULT_HUMBLE='data'
CONTENT_PATH_DEFAULT_GOG='data/noarch/game'
CONTENT_LIBS_BIN32_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib32"
CONTENT_LIBS_BIN32_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib32"
# TODO: Check if we can drop the shipped SDL2_mixer library in favour of a system-provided one.
CONTENT_LIBS_BIN32_FILES='
libSDL2_mixer-2.0.so.0'
CONTENT_LIBS_BIN64_PATH_HUMBLE="${CONTENT_PATH_DEFAULT_HUMBLE}/lib64"
CONTENT_LIBS_BIN64_PATH_GOG="${CONTENT_PATH_DEFAULT_GOG}/lib64"
# TODO: Check if we can drop the shipped SDL2_mixer library in favour of a system-provided one.
CONTENT_LIBS_BIN64_FILES='
libSDL2_mixer-2.0.so.0'
CONTENT_GAME_BIN32_FILES='
unepic32'
CONTENT_GAME_BIN64_FILES='
unepic64'
CONTENT_GAME_DATA_FILES='
data
image
sound
voices
unepic.png
omaps
dictios_pc'

APP_MAIN_EXE_BIN32='unepic32'
APP_MAIN_EXE_BIN64='unepic64'
APP_MAIN_ICON_HUMBLE='unepic.png'
APP_MAIN_ICON_GOG='../support/icon.png'

PACKAGES_LIST='PKG_BIN32 PKG_BIN64 PKG_DATA'

PKG_DATA_ID="${GAME_ID}-data"
PKG_DATA_DESCRIPTION='data'

PKG_BIN32_ARCH='32'
PKG_BIN64_ARCH='64'
PKG_BIN_DEPS="$PKG_DATA_ID"
PKG_BIN32_DEPS="$PKG_BIN_DEPS"
PKG_BIN64_DEPS="$PKG_BIN_DEPS"
PKG_BIN_DEPENDENCIES_LIBRARIES='
libc.so.6
libGL.so.1
libm.so.6
libSDL2-2.0.so.0
libstdc++.so.6
libz.so.1'
PKG_BIN32_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"
PKG_BIN64_DEPENDENCIES_LIBRARIES="$PKG_BIN_DEPENDENCIES_LIBRARIES"

# Load common functions

target_version='2.25'

PLAYIT_LIB_PATHS="
$PWD
${XDG_DATA_HOME:="${HOME}/.local/share"}/play.it
/usr/local/share/games/play.it
/usr/local/share/play.it
/usr/share/games/play.it
/usr/share/play.it"

if [ -z "$PLAYIT_LIB2" ]; then
	for playit_lib_path in $PLAYIT_LIB_PATHS; do
		if [ -e "${playit_lib_path}/libplayit2.sh" ]; then
			PLAYIT_LIB2="${playit_lib_path}/libplayit2.sh"
			break
		fi
	done
fi
if [ -z "$PLAYIT_LIB2" ]; then
	printf '\n\033[1;31mError:\033[0m\n'
	printf 'libplayit2.sh not found.\n'
	exit 1
fi
. "$PLAYIT_LIB2"

# Extract game data

archive_extraction 'SOURCE_ARCHIVE'

# Include game icons

PKG='PKG_DATA'
icons_inclusion

# Include game data

content_inclusion_default

# Delete temporary files

rm --recursive "${PLAYIT_WORKDIR}/gamedata"

# Write launchers

for PKG in 'PKG_BIN32' 'PKG_BIN64'; do
	launchers_write
done

# Build packages

packages_generation

# Print instructions

print_instructions

# Clean up

rm --recursive "$PLAYIT_WORKDIR"

exit 0
